Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1391)

Unified Diff: cc/surfaces/surface_id.h

Issue 2661543002: Rename LocalFrameId to LocalSurfaceId (Closed)
Patch Set: c Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/surfaces/surface_hittest_unittest.cc ('k') | cc/surfaces/surface_id.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/surfaces/surface_id.h
diff --git a/cc/surfaces/surface_id.h b/cc/surfaces/surface_id.h
index fe21851076ce9e33b8b800fc56f6382c9f55f42c..25db499b5cb2ee8a052006bfa0981a6439a5ea90 100644
--- a/cc/surfaces/surface_id.h
+++ b/cc/surfaces/surface_id.h
@@ -13,7 +13,7 @@
#include "base/format_macros.h"
#include "base/hash.h"
#include "cc/surfaces/frame_sink_id.h"
-#include "cc/surfaces/local_frame_id.h"
+#include "cc/surfaces/local_surface_id.h"
#include "mojo/public/cpp/bindings/struct_traits.h"
namespace cc {
@@ -27,42 +27,42 @@ class SurfaceId {
constexpr SurfaceId(const SurfaceId& other) = default;
// A SurfaceId consists of two components: FrameSinkId and LocalFrameId.
// A |frame_sink_id| consists of two components; one is allocated by the
// display compositor service and one is allocated by the client. The
// |frame_sink_id| uniquely identifies a FrameSink (and frame source).
- // A |local_frame_id| is a sequentially allocated ID generated by the frame
+ // A |local_surface_id| is a sequentially allocated ID generated by the frame
// source that uniquely identifies a sequential set of frames of the same size
// and device scale factor.
constexpr SurfaceId(const FrameSinkId& frame_sink_id,
- const LocalFrameId& local_frame_id)
- : frame_sink_id_(frame_sink_id), local_frame_id_(local_frame_id) {}
+ const LocalSurfaceId& local_surface_id)
+ : frame_sink_id_(frame_sink_id), local_surface_id_(local_surface_id) {}
bool is_valid() const {
- return frame_sink_id_.is_valid() && local_frame_id_.is_valid();
+ return frame_sink_id_.is_valid() && local_surface_id_.is_valid();
}
size_t hash() const {
return base::HashInts(static_cast<uint64_t>(frame_sink_id_.hash()),
- static_cast<uint64_t>(local_frame_id_.hash()));
+ static_cast<uint64_t>(local_surface_id_.hash()));
}
const FrameSinkId& frame_sink_id() const { return frame_sink_id_; }
- const LocalFrameId& local_frame_id() const { return local_frame_id_; }
+ const LocalSurfaceId& local_surface_id() const { return local_surface_id_; }
std::string ToString() const;
bool operator==(const SurfaceId& other) const {
return frame_sink_id_ == other.frame_sink_id_ &&
- local_frame_id_ == other.local_frame_id_;
+ local_surface_id_ == other.local_surface_id_;
}
bool operator!=(const SurfaceId& other) const { return !(*this == other); }
bool operator<(const SurfaceId& other) const {
- return std::tie(frame_sink_id_, local_frame_id_) <
- std::tie(other.frame_sink_id_, other.local_frame_id_);
+ return std::tie(frame_sink_id_, local_surface_id_) <
+ std::tie(other.frame_sink_id_, other.local_surface_id_);
}
private:
@@ -70,7 +70,7 @@ class SurfaceId {
// See SurfaceIdAllocator::GenerateId.
FrameSinkId frame_sink_id_;
- LocalFrameId local_frame_id_;
+ LocalSurfaceId local_surface_id_;
};
std::ostream& operator<<(std::ostream& out, const SurfaceId& surface_id);
« no previous file with comments | « cc/surfaces/surface_hittest_unittest.cc ('k') | cc/surfaces/surface_id.cc » ('j') | no next file with comments »
@@ -27,42 +27,42 @@ class SurfaceId {
constexpr SurfaceId(const SurfaceId& other) = default;
- // A SurfaceId consists of two components: FrameSinkId and LocalFrameId.
+ // A SurfaceId consists of two components: FrameSinkId and LocalSurfaceId.
// A |frame_sink_id| consists of two components; one is allocated by the
// display compositor service and one is allocated by the client. The

Powered by Google App Engine
This is Rietveld 408576698